/* CUnitTester http://www.gethos.net/opensource/cunit
 * unittester.c -- provides the main() entry point to launch the tester
 *
 * Copyright 2003 by Stewart Gebbie
 * For license terms, see the file COPYING in the top directory.
 */
/* $Id: unittester.c,v 1.21 2005/01/05 21:16:41 stewart Exp $ */
#include "config.h"
#include <libcunit/unittester.h>

#include <libcunit/world.h>
#include <libcunit/run.h>
#include <libcunit/compile.h>
#include <libcunit/info.h>
#include <libcunit/show.h>
#include <libcunit/parseargs.h>

/* 
 * This is the entry point for the 'C' unit test program.
 *
 * This will search for all DSO with a name of the form libtest_....so
 * and comiple a list of test suites. After this it will run each
 * suite and hence each test in each suite.
 *
 */

/* compiles a list of test suites and then runs them */
int RunTester (int argc, char* argv[])
{
	utest_world world;
	int anyBadTests = 0;

	ShowBootstrap();

	InitWorld(&world);

	/* check command line parameters */
	ParseArgs (argc, argv, &world);

	ShowInit(&world);

	/* banner */
	ShowBanner (&world);

	CompileWorld(&world);

	/* init timers */
	InitWorldTimers(&world);

	RunWorld(&world);

	/* final timers */
	FiniWorldTimers(&world);
	
	ShowInfo (&world);
	anyBadTests = world.badTestCount ? 1 : 0;

	FiniWorld (&world);

	ShowFini();

	return anyBadTests;
}

int main(int argc, char* argv[])
{
	int ret;

	ret = RunTester(argc, argv);

	return ret;
}
