/* CUnitTester http://www.gethos.net/opensource/cunit
 * load.c -- loads test suites from shared objects
 *
 * Copyright 2003 by Stewart Gebbie
 * For license terms, see the file COPYING in the top directory.
 */
/* $Id: add.c,v 1.2 2005/01/05 20:53:56 stewart Exp $ */
#include "config.h"
#include "unittester.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <dlfcn.h>
#include <sys/types.h>
#include <regex.h>

#include "load.h"
#include "show.h"

/* count how many tests there are in a test suite */
int CountTests (utest_suite *suite)
{
	int c;
	for (c = 0; suite->tests[c].theTest != NULL; c++);
	return c;
}


/* build up the world of tests. */
utest_suite_stub* CreateStub (utest_suite* suite, const char* libpath)
{
	utest_suite_stub* stub = NULL;

	stub = (utest_suite_stub*)malloc(sizeof(utest_suite_stub));
	stub->suite = suite;
	stub->testCount = CountTests (stub->suite);
	strncpy(stub->libpath, libpath, MAXUTESTPATHLEN);
	stub->next = NULL;

	return stub;
}


void DestroyStub (utest_suite_stub* stub)
{
	uassert (stub);
	free (stub);
}


void AddSuite (utest_world* world, const char* libpath)
{
	utest_suitelib sl;
	utest_suite* suite;
	utest_suite_stub* stub = NULL;

	/* load DSO */
	suite = LoadSuite (libpath, &sl);

	stub = CreateStub (suite, libpath);

	if (FilterSuite (world, suite))
	{
		ShowAddTest (stub);
		AppendStub (world, stub);
	}
	else
	{
		ShowSkipTest (stub);
		DestroyStub (stub);
	}

	/* unload DSO */
	UnloadSuite (&sl);
}
