/* CUnitTester http://www.gethos.net/opensource/cunit
 * info.c -- manages info produced by running tests
 *
 * Copyright 2003 by Stewart Gebbie
 * For license terms, see the file COPYING in the top directory.
 */
/* $Id: info.c,v 1.5 2004/12/27 13:27:38 stewart Exp $ */
#include "config.h"
#include "unittester.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>

#include "info.h"

/* UTestFillInfo is passed as a function pointer in the info struct */
void UTestFillInfo (utest_info* info, int line, const char* file, const char* msg,...)
{
	va_list ap;
	
	uassert (info);
	uassert (file);
	uassert (msg);

	info->line = line;
	
	va_start (ap, msg);
	vsnprintf (info->msg, MAXUTESTMESGLEN, msg, ap);
	va_end (ap);
	
	strncpy (info->file, file, MAXUTESTFILELEN);
}


utest_info* CopyInfo (utest_info* info)
{
	utest_info* copy = NULL;
	uassert (info);
	copy = (utest_info*)malloc(sizeof(utest_info));

	copy->line = info->line;
	copy->status = info->status;
	strncpy (copy->msg, info->msg, MAXUTESTMESGLEN);
	strncpy (copy->file, info->file, MAXUTESTFILELEN);
	strncpy (copy->suiteName, info->suiteName, MAXUTESTNAMELEN);
	strncpy (copy->testName, info->testName, MAXUTESTNAMELEN);
	copy->next = NULL;

	return copy;
}

void AddInfo (utest_world* world, utest_info* info)
{
	utest_info* copy = NULL;
	uassert (world);
	uassert (info);

	copy = CopyInfo (info);
	AppendInfo (world, copy);

	world->finTestCount++;
	if (info->status)
		world->goodTestCount++;
	else
		world->badTestCount++;
}

void InitInfo (utest_info* info, const char* suiteName, const char* testName)
{
	info->line = 0; 
	info->status = true; 
	info->file[0] = '\0'; 
	info->msg[0] = '\0';

	strncpy (info->suiteName, suiteName, MAXUTESTNAMELEN);
	strncpy (info->testName, testName, MAXUTESTNAMELEN);

	info->logerror = &UTestFillInfo;
}
