/* CUnitTester http://www.gethos.net/opensource/cunit
 * parseargs.c -- parses the command line arguments and updates the world
 *
 * Copyright 2003 by Stewart Gebbie
 * For license terms, see the file COPYING in the top directory.
 */
/* $Id: parseargs.c,v 1.1 2004/12/23 10:22:56 stewart Exp $ */
#include "config.h"
#include "unittester.h"

#include <getopt.h>
#include <stdlib.h>

#include "world.h"
#include "info.h"
#include "show.h"

int Usage (int argc, char* argv[], const char* errmsg)
{
	ShowUsage (argc, argv, errmsg);
	exit(1);
}

int ParseArgs (int argc, char* argv[], utest_world* world)
{
	int showHelp = 0;
	int c;

	/* check command line parameters */
	while (1)
	{
		int option_index = 0;
		static struct option long_options[] = {
			{"help", 0, 0, 'h'},
			{"root", 1, 0, 'r'},
			{"filter", 1, 0, 'f'},
			{"output", 1, 0, 'o'},
			{0, 0, 0, 0}
		};

		c = getopt_long (argc, argv, "hr:f:o:", long_options, &option_index);
		if (c == -1) break;

		switch (c) {
			case 0:
				break;
			case 'h':
				showHelp = 1;
				break;
			case 'r':
				world->rootDir = optarg;
				break;
			case 'f':
				world->filter = optarg;
				break;
			case 'o':
				world->output = optarg;
				break;
			default:
				ShowError ("?? getopt returned character code 0%o ??\n", c);
		}
	}

	if (optind < argc) {
		// assume that non-getopt argv elements are root directories
		while (optind < argc)
			world->rootDir = argv[optind++];
	}

	if (showHelp)
	{
		Usage (argc, argv, "Help");
	}

	return 1;
}
