/* CUnitTester http://www.gethos.net/opensource/cunit
 * compile.c -- builds a list of suites and tests
 *
 * Copyright 2003 by Stewart Gebbie
 * For license terms, see the file COPYING in the top directory.
 */
/* $Id: recursedir.c,v 1.1 2004/12/23 10:33:00 stewart Exp $ */
#include "config.h"
#include "unittester.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <alloca.h>
#include <dirent.h>
#include <fnmatch.h>
#include <sys/types.h>
#include <sys/stat.h>

#include "recursedir.h"
#include "load.h"
#include "show.h"

/*
 * Compiling:
 * search for DSOs with names of the form libtest....so and 
 * add the test suites and to the world
 */

void RecurseDir(utest_world* world, const char* path, int depth)
{
	DIR* currdir;
	struct dirent* dent;
	int ret;

	currdir = opendir(path);
	if (!currdir) 
	{
		ShowError (
				"ERROR: opendir(%s) failed to open search directory: %s\n", 
				path, strerror (errno));
	}
	uassert (currdir);

	for (dent = readdir(currdir); dent !=NULL; dent = readdir(currdir))
	{
		int fnm;
		size_t flen = strlen(path) + strlen(dent->d_name)+2;
		char* fpath = alloca(flen);
		uassert (fpath);

		snprintf(fpath,flen,"%s/%s", path, dent->d_name);
		fnm = fnmatch("libtest_*.so",dent->d_name,0);
		uassert (fnm == 0 || fnm == FNM_NOMATCH);
		if (fnm == 0)
		{/* add to world */
			AddSuite (world, fpath);
		}
		if (dent->d_name[0] != '.')
		{
			struct stat sbuf;
			int ret;

			ret = stat(fpath, &sbuf);
			if (ret != 0)
			{
				ShowError (
						"ERROR: stat(%s,...) failed during suite search: %s\n", 
						fpath, strerror (errno));
				if (errno == ENOENT) continue;
			}
			uassert (ret == 0);

			if (S_ISDIR(sbuf.st_mode))
				RecurseDir(world, fpath, depth+1);
		}
	}

	ret = closedir(currdir);
	uassert (ret == 0);
}
