/* CUnitTester http://www.gethos.net/opensource/cunit
 * run.c -- runs the actual tests in all the suites
 *
 * Copyright 2003 by Stewart Gebbie
 * For license terms, see the file COPYING in the top directory.
 */
/* $Id: run.c,v 1.10 2005/01/05 20:53:56 stewart Exp $ */
#include "config.h"
#include "unittester.h"

#include <stdio.h>
#include <stdlib.h>

#include "run.h"
#include "info.h"
#include "load.h"
#include "show.h"


int RunSuite (utest_world* world, utest_suite_stub* stub)
{
	int t;
	int testStatus;
	utest_suite* suite = stub->suite;
	utest_info uinfo;

	/* run suite initialiser */
	InitInfo(&uinfo, suite->name, "Initialiser");
	if (suite->initialiser)
	{
		ShowPreInit (world);
		testStatus = suite->initialiser (&uinfo);
		uinfo.status = testStatus;
		ShowPostInit (world, &uinfo);
		if (!testStatus) goto suite_init_bad;
	}
	/* run each test */
	for (t = 0; t < stub->testCount; t++)
	{
		ShowPreFixture (world, &suite->tests[t]);

		/* run setup */
		InitInfo(&uinfo, suite->name, "Setup");
		if (suite->setup)
		{
			ShowPreSetup (world);
			testStatus = suite->setup (&uinfo);
			uinfo.status = testStatus;
			ShowPostSetup (world, &uinfo);
			if (!testStatus) goto stage_setup_bad;
		}

		/* run test */
		InitInfo(&uinfo, suite->name, suite->tests[t].name);
		uassert (suite->tests[t].theTest != NULL);
		ShowPreTest (world);
		testStatus = suite->tests[t].theTest (&uinfo);
		uinfo.status = testStatus;
		ShowPostTest (world, &uinfo);

		world->addinfo (world, &uinfo);

		/* run teardown */
		InitInfo(&uinfo, suite->name, "Teardown");
		if (suite->teardown)
		{
			ShowPreTeardown (world);
			testStatus = suite->teardown (&uinfo);
			uinfo.status = testStatus;
			ShowPostTeardown (world, &uinfo);
			if (!testStatus) goto stage_teardown_bad;
		}

		ShowPostFixture (world, &suite->tests[t]);
	}
	/* run suite finialiser */
	InitInfo(&uinfo, suite->name, "Finaliser");
	if (suite->finaliser)
	{
		ShowPreFini (world);
		testStatus = suite->finaliser (&uinfo);
		uinfo.status = testStatus;
		ShowPostFini (world, &uinfo);
		if (!testStatus) goto suite_fini_bad;
	}

	/* end of suite suiteok: */
	world->finSuiteCount++;
	return true;

stage_setup_bad:
	ShowError ("\nERROR: test setup failed for suite: %s\n", suite->name);
	goto stage_bad;
stage_teardown_bad:
	ShowError ("\nERROR: test teardown failed for suite: %s\n", suite->name);
	goto stage_bad;
stage_bad:
	ShowPostFixture (world, &suite->tests[t]);
	return false;

suite_init_bad:
	ShowError ("\nERROR: suite init failed for suite: %s\n", suite->name);
	return false;
suite_fini_bad:
	ShowError ("\nERROR: suite fini failed for suite: %s\n", suite->name);
	return false;

}


/* run each suite in the world */
void RunWorld (utest_world* world)
{
	utest_suite_stub *current = NULL;

	if (world->testCount == 0)
	{
		ShowMsg ("There are no tests to run.\n");
		return;
	}

	ShowPreRun (world);
	for (current = world->stubHead; current != NULL; current = current->next)
	{
		utest_suitelib sl;
		utest_suite* suite;

		suite = LoadSuite (current->libpath, &sl);
		uassert (suite);

		/* ensure that we reset the suite pointer as it may have 
		 * changed after the first dlopen()
		 * (thanks Jaco Breitenbach <jjb@herfs.net>)
		 */
		current->suite = suite;

		ShowPreSuite(suite);
		RunSuite (world, current);
		ShowPostSuite(suite);

		UnloadSuite (&sl);
	}
	ShowPostRun (world);

#if 0
	if (world->testCount != world->finTestCount)
		ShowError ("\nNOT ALL TESTS RAN! expected %d but only %d completed\n",
				world->testCount, world->finTestCount);
	if (world->suiteCount != world->finSuiteCount)
		ShowError ("\nNOT ALL SUITES RAN! expected %d but only %d completed\n",
				world->suiteCount, world->finSuiteCount);
#endif
}
