/* CUnitTester http://www.gethos.net/opensource/cunit
 * show.c -- handles all output that the user sees
 *           this is achieved by delgating to a given driver
 *
 * Copyright 2003 by Stewart Gebbie
 * For license terms, see the file COPYING in the top directory.
 */
/* $Id: show.c,v 1.20 2005/01/05 20:53:56 stewart Exp $ */
#include "config.h"
#include "unittester.h"

#include <stdio.h>
#include <stdarg.h>
#include <math.h>
#include <string.h>

#include "show.h"
#include "show_colour.h"
#include "show_xml.h"
#include "show_mono.h"


static ShowFunctions *showFunctions = NULL;

void ShowBootstrap()
{
	showFunctions = getColourShowFunctions();
}

void ShowInit (utest_world* world)
{
	uassert (world);
	if (world->output)
	{
		if (strcmp ("xml", world->output) == 0) showFunctions = getXmlShowFunctions();
		if (strcmp ("colour", world->output) == 0) showFunctions = getColourShowFunctions();
		if (strcmp ("mono", world->output) == 0) showFunctions = getMonoShowFunctions();
	}
	else
	{
		showFunctions = getColourShowFunctions();
	}

	if (showFunctions->ShowInit) showFunctions->ShowInit ();
}

void ShowFini (void)
{
	if (showFunctions->ShowFini) showFunctions->ShowFini ();
	showFunctions = NULL;
}

void ShowError_va (const char* fmt, va_list ap)
{
	showFunctions->ShowError_va (fmt, ap);
}

void ShowMsg_va (const char* fmt, va_list ap)
{
	showFunctions->ShowMsg_va (fmt, ap);
}

void ShowUsage (int argc, char* argv[], const char* errmsg)
{
	showFunctions->ShowUsage (argc, argv, errmsg);
}


void ShowInfo (utest_world* world)
{
	showFunctions->ShowInfo (world);
}


void ShowBanner (utest_world* world)
{
	showFunctions->ShowBanner (world);
}


void ShowAddTest (utest_suite_stub* stub)
{
	showFunctions->ShowAddTest (stub);
}

void ShowSkipTest (utest_suite_stub* stub)
{
	showFunctions->ShowSkipTest (stub);
}

void ShowError (const char* fmt, ...)
{
	va_list ap;

	va_start(ap, fmt);
	ShowError_va (fmt, ap);
	va_end(ap);
}

void ShowMsg (const char* fmt, ...)
{
	va_list ap;

	va_start(ap, fmt);
	ShowMsg_va (fmt, ap);
	va_end(ap);
}

void ShowPreCompile (utest_world* world)
{
	if (showFunctions->ShowPreCompile) showFunctions->ShowPreCompile (world);
}
void ShowPostCompile (utest_world* world)
{
	if (showFunctions->ShowPostCompile) showFunctions->ShowPostCompile (world);
}

void ShowPreRun (utest_world* world)
{
	if (showFunctions->ShowPreRun) showFunctions->ShowPreRun (world);
}
void ShowPostRun (utest_world* world)
{
	if (showFunctions->ShowPostRun) showFunctions->ShowPostRun (world);
}

void ShowPreSuite (utest_suite* suite)
{
	if (showFunctions->ShowPreSuite) showFunctions->ShowPreSuite (suite);
}

void ShowPostSuite (utest_suite* suite)
{
	if (showFunctions->ShowPostSuite) showFunctions->ShowPostSuite (suite);
}


void ShowPreInit (utest_world* world)
{
	if (showFunctions->ShowPreInit) showFunctions->ShowPreInit (world);
}

void ShowPostInit (utest_world* world, utest_info* info)
{
	if (showFunctions->ShowPostInit) showFunctions->ShowPostInit (world, info);
}

void ShowPreFixture (utest_world* world, utest_test* test)
{
	if (showFunctions->ShowPreFixture) showFunctions->ShowPreFixture (world, test);
}

void ShowPostFixture (utest_world* world, utest_test* test)
{
	if (showFunctions->ShowPostFixture) showFunctions->ShowPostFixture (world, test);
}


void ShowPreSetup (utest_world* world)
{
	if (showFunctions->ShowPreSetup) showFunctions->ShowPreSetup (world);
}

void ShowPostSetup (utest_world* world, utest_info* info)
{
	if (showFunctions->ShowPostSetup) showFunctions->ShowPostSetup (world, info);
}


void ShowPreTest (utest_world* world)
{
	if (showFunctions->ShowPreTest) showFunctions->ShowPreTest (world);
}

void ShowPostTest (utest_world* world, utest_info* info)
{
	if (showFunctions->ShowPostTest) showFunctions->ShowPostTest (world, info);
}


void ShowPreTeardown (utest_world* world)
{
	if (showFunctions->ShowPreTeardown) showFunctions->ShowPreTeardown (world);
}

void ShowPostTeardown (utest_world* world, utest_info* info)
{
	if (showFunctions->ShowPostTeardown) showFunctions->ShowPostTeardown (world, info);
}


void ShowPreFini (utest_world* world)
{
	if (showFunctions->ShowPreFini) showFunctions->ShowPreFini (world);
}

void ShowPostFini (utest_world* world, utest_info* info)
{
	if (showFunctions->ShowPostFini) showFunctions->ShowPostFini (world, info);
}
