/* 
 * show.h 
 *
 * Copyright 2003 by Stewart Gebbie
 * For license terms, see the file COPYING in the top directory.
 */
#ifndef CUNIT_SHOW_H
#define CUNIT_SHOW_H

#include <stdarg.h>

#include <libcunit/world.h>

#define CUNIT_BANNER "CUnitTester (" CUNIT_VERSION ") by Stewart Gebbie [cunit@gethos.net] 2005"
#define CUNIT_URL "http://www.gethos.net/opensource/cunit"

typedef struct ShowFunctions_tag
{
	void (*ShowInit) (void);
	void (*ShowFini) (void);
	void (*ShowError_va) (const char* fmt, va_list ap);
	void (*ShowMsg_va) (const char* fmt, va_list ap);
	void (*ShowUsage) (int argc, char* argv[], const char* errmsg);
	void (*ShowBanner) (utest_world* world);
	void (*ShowAddTest) (utest_suite_stub* stub);
	void (*ShowSkipTest) (utest_suite_stub* stub);
	void (*ShowInfo) (utest_world* world);

	void (*ShowPreCompile) (utest_world* world);
	void (*ShowPostCompile) (utest_world* world);
	void (*ShowPreRun) (utest_world* world);
	void (*ShowPostRun) (utest_world* world);
	void (*ShowPreSuite) (utest_suite* suite);
	void (*ShowPostSuite) (utest_suite* suite);
	void (*ShowPreInit) (utest_world* world);
	void (*ShowPostInit) (utest_world* world, utest_info* info);
	void (*ShowPreFixture) (utest_world* world, utest_test* test);
	void (*ShowPostFixture) (utest_world* world, utest_test* test);
	void (*ShowPreSetup) (utest_world* world);
	void (*ShowPostSetup) (utest_world* world, utest_info* info);
	void (*ShowPreTest) (utest_world* world);
	void (*ShowPostTest) (utest_world* world, utest_info* info);
	void (*ShowPreTeardown) (utest_world* world);
	void (*ShowPostTeardown) (utest_world* world, utest_info* info);
	void (*ShowPreFini) (utest_world* world);
	void (*ShowPostFini) (utest_world* world, utest_info* info);
} ShowFunctions;

void ShowBootstrap ();
void ShowInit (utest_world* world);
void ShowFini (void);

void ShowError (const char* fmt,...);
void ShowMsg (const char* fmt,...);

void ShowUsage (int argc, char* argv[], const char* errmsg);

void ShowBanner (utest_world* world);
void ShowInfo (utest_world* world);

void ShowAddTest (utest_suite_stub* stub);
void ShowSkipTest (utest_suite_stub* stub);

void ShowPreCompile (utest_world* world);
void ShowPostCompile (utest_world* world);

void ShowPreRun (utest_world* world);
void ShowPostRun (utest_world* world);

void ShowPreSuite (utest_suite* suite);
void ShowPostSuite (utest_suite* suite);

void ShowPreInit (utest_world* world);
void ShowPostInit (utest_world* world, utest_info* info);

void ShowPreFixture (utest_world* world, utest_test* test);
void ShowPostFixture (utest_world* world, utest_test* test);

void ShowPreSetup (utest_world* world);
void ShowPostSetup (utest_world* world, utest_info* info);

void ShowPreTest (utest_world* world);
void ShowPostTest (utest_world* world, utest_info* info);

void ShowPreTeardown (utest_world* world);
void ShowPostTeardown (utest_world* world, utest_info* info);

void ShowPreFini (utest_world* world);
void ShowPostFini (utest_world* world, utest_info* info);

#endif /* CUNIT_SHOW_H */
