/* CUnitTester http://www.gethos.net/opensource/cunit
 * world.c -- top level context information containing stats and suites
 *
 * Copyright 2003 by Stewart Gebbie
 * For license terms, see the file COPYING in the top directory.
 */
/* $Id: world.c,v 1.6 2004/12/23 08:45:50 stewart Exp $ */
#include "config.h"
#include "unittester.h"

#include <stdlib.h>
#include <stdio.h>

#include "world.h"
#include "info.h"

/* initialises the run config and counters */
void InitWorld (utest_world* world)
{
	world->rootDir = ".";
	world->filter = NULL;
	world->output = NULL;
	world->compiledFilter = NULL;
	
	world->suiteCount = 0;
	world->testCount = 0;

	world->finSuiteCount = 0;
	world->finTestCount = 0;

	world->badTestCount = 0;
	world->goodTestCount = 0;

	world->secStart = 0;
	world->usecStart = 0;
	world->secEnd = 0;
	world->usecEnd = 0;

	world->addstub = NULL;
	world->stubHead = NULL;
	world->stubTail = NULL;

	world->addinfo = &AddInfo;
	world->infoHead = NULL;
	world->infoTail = NULL;
}


void FiniWorld (utest_world* world)
{
	utest_info* currentInfo = NULL;
	utest_suite_stub* currentStub = NULL;

	world->rootDir = ".";
	world->filter = NULL;

	world->suiteCount = 0;
	world->testCount = 0;

	world->finSuiteCount = 0;
	world->finTestCount = 0;

	world->badTestCount = 0;
	world->goodTestCount = 0;

	world->secStart = 0;
	world->usecStart = 0;
	world->secEnd = 0;
	world->usecEnd = 0;

	// free the stubs list
	currentStub = world->stubHead;
	while (currentStub)
	{
		utest_suite_stub* nextStub = currentStub->next;
		free (currentStub);
		currentStub = nextStub;
	}
	world->addstub = NULL;
	world->stubHead = NULL;
	world->stubTail = NULL;

	// free the info list
	currentInfo = world->infoHead;
	while (currentInfo)
	{
		utest_info* nextInfo = currentInfo->next;
		free (currentInfo);
		currentInfo = nextInfo;
	}
	world->addinfo = NULL;
	world->infoHead = NULL;
	world->infoTail = NULL;
}


void AppendStub (utest_world* world, utest_suite_stub* stub)
{
	uassert (world);
	uassert (stub);

	world->suiteCount += 1;
	world->testCount += stub->testCount;
	if (world->stubHead == NULL)
	{
		world->stubHead = stub;
		world->stubTail = stub;
	}
	else
	{
		world->stubTail->next = stub;
		world->stubTail = stub;
	}
}


void AppendInfo (utest_world* world, utest_info* info)
{
	uassert (world);
	uassert (info);

	if (world->infoHead == NULL)
	{
		world->infoHead = info;
		world->infoTail = info;
	}
	else
	{
		world->infoTail->next = info;
		world->infoTail = info;
	}
}
